/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch das
 * Ministerium für Energiewende, Klimaschutz, Umwelt und Natur
 * Zentrales IT-Management
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.formcycle;

import static java.util.Objects.*;
import static org.apache.commons.lang3.StringUtils.*;

import java.util.Properties;

import de.ozgcloud.formcycle.errorhandling.UserErrorDispatcher;
import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
public class PluginPropertiesMapper {

	private final UserErrorDispatcher userErrorDispatcher;

	public OzgCloudConfig mapProperties(Properties pluginProperties) {
		if (isNull(pluginProperties) || pluginProperties.isEmpty()) {
			return OzgCloudConfig.builder().build();
		}
		return OzgCloudConfig.builder()
				.eingangsAdapterUrl(pluginProperties.getProperty(OzgCloudConfig.KEY_EINGANGSADAPTER_URL))
				.proxyConfig(mapProxyProperties(pluginProperties))
				.build();
	}

	public ProxyConfig mapProxyProperties(Properties pluginProperties) {
		return ProxyConfig.builder()
				.host(pluginProperties.getProperty(ProxyConfig.KEY_PROXY_HOST))
				.port(getPort(pluginProperties))
				.user(pluginProperties.getProperty(ProxyConfig.KEY_PROXY_USER))
				.password(pluginProperties.getProperty(ProxyConfig.KEY_PROXY_PASSWORD))
				.build();
	}

	Integer getPort(Properties pluginProperties) {
		var portProperty = pluginProperties.getProperty(ProxyConfig.KEY_PROXY_PORT);
		if (isBlank(portProperty)) {
			return null;
		}
		var port = Utils.parsePort(portProperty);
		if (isNull(port)) {
			userErrorDispatcher.sendWrongProxyPortFormatMessage();
		}
		return port;
	}

}
